package com.ruoyi.ykmap.controller;

import com.ruoyi.common.annotation.DataSource;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.DataSourceType;
import com.ruoyi.ykmap.entity.response.*;
import com.ruoyi.ykmap.service.LineService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 大屏线路接口
 * @author du
 * @since 2024/8/14 10:40
 */
@RestController
@RequestMapping("/ykmap/line")
@Api(tags = "大屏线路接口")
public class LineController extends BaseController {

    @Resource
    private LineService lineService;

    @ApiOperation(value = "根据车辆id查询线路,装备,人员,标的物", response = GetCarIdInfoResponse.class)
    @GetMapping("/getCarIdInfo/{id}")
    public AjaxResult getCarIdInfo(@PathVariable String id) {
        return success(lineService.getCarIdInfo(id));
    }


    @ApiOperation(value = "任务明细弹窗线路信息", response = SelectLineInfoResponse.class)
    @GetMapping("/selectLineInfo/{id}")
    public AjaxResult selectLineInfo(@PathVariable String id) {
        return success(lineService.selectLineInfo(id));
    }

    @ApiOperation(value = "任务明细弹窗装备信息", response = EquipResponse.class)
    @GetMapping("/equip/{id}")
    public AjaxResult equip(@PathVariable String id) {
        return success(lineService.equip(id));
    }

    @ApiOperation(value = "任务明细弹窗人员信息", response = UserInfoResponse.class)
    @GetMapping("/userInfo/{id}")
    public AjaxResult userInfo(@PathVariable String id) {
        return success(lineService.userInfo(id));
    }

    @ApiOperation(value = "任务明细弹窗标的物信息", response = ItemsResponse.class)
    @GetMapping("/items/{id}")
    public AjaxResult items(@PathVariable String id) {
        return success(lineService.items(id));
    }

    @ApiOperation(value = "线路模板具体信息", response = LineTemplateResponse.class)
    @GetMapping("/lineTemplate")
    @DataSource(value = DataSourceType.SLAVE)
    public AjaxResult lineTemplate(String area) {
        return success(lineService.lineTemplate(area));
    }

    @ApiOperation(value = "业务已覆盖省份清单", response = SearchCityResponse.class)
    @GetMapping("/searchCity")
    @DataSource(value = DataSourceType.SLAVE)
    public AjaxResult searchCity() {
        return success(lineService.searchCity());
    }

    @ApiOperation(value = "业务已覆盖省份个数", response = SearchCityCountResponse.class)
    @GetMapping("/searchCityCount")
    @DataSource(value = DataSourceType.SLAVE)
    public AjaxResult searchCityCount() {
        return success(lineService.searchCityCount());
    }
}
