package com.ruoyi.ykmap.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.ruoyi.ykmap.entity.response.*;
import com.ruoyi.ykmap.mapper.LineMapper;
import com.ruoyi.ykmap.service.LineService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.util.List;

/**
 * 大屏线路业务处理层
 *
 * @author du
 * @since 2024/8/14 10:44
 */
@Service
public class LineServiceImpl implements LineService {

    @Resource
    private LineMapper lineMapper;

    /**
     * 任务明细弹窗线路信息
     */
    @Override
    public SelectLineInfoResponse selectLineInfo(String id) {
        return lineMapper.selectLineInfo(id);
    }

    /**
     * 任务明细弹窗装备信息
     */
    @Override
    public List<EquipResponse> equip(String id) {
        return lineMapper.equip(id);
    }

    /**
     * 任务明细弹窗人员信息
     */
    @Override
    public List<UserInfoResponse> userInfo(String id) {
        return lineMapper.userInfo(id);
    }

    /**
     * 任务明细弹窗标的物信息
     */
    @Override
    public ItemsResponse items(String id) {
        return lineMapper.items(id);
    }

    /**
     * 线路模板具体信息
     */
    @Override
    public List<LineTemplateResponse> lineTemplate(String area) {
        LocalDate now = LocalDate.now();
        if (now.getDayOfMonth() < 26) {
            LocalDate a1 = now.minusMonths(2).withDayOfMonth(26);
            LocalDate a2 = now.minusMonths(1).withDayOfMonth(25);
            return lineMapper.lineTemplate(area, a1, a2);
        } else {
            LocalDate a1 = now.minusMonths(1).withDayOfMonth(26);
            LocalDate a2 = now.withDayOfMonth(25);
            return lineMapper.lineTemplate(area, a1, a2);
        }
    }

    /**
     * 业务已覆盖省份清单
     */
    @Override
    public List<SearchCityResponse> searchCity() {
        LocalDate now = LocalDate.now();
        if (now.getDayOfMonth() < 26) {
            LocalDate a1 = now.minusMonths(2).withDayOfMonth(26);
            LocalDate a2 = now.minusMonths(1).withDayOfMonth(25);
            return lineMapper.searchCity(a1, a2);
        } else {
            LocalDate a1 = now.minusMonths(1).withDayOfMonth(26);
            LocalDate a2 = now.withDayOfMonth(25);
            return lineMapper.searchCity(a1, a2);
        }
    }

    /**
     * 业务已覆盖省份个数
     */
    @Override
    public SearchCityCountResponse searchCityCount() {
        LocalDate now = LocalDate.now();
        if (now.getDayOfMonth() < 26) {
            LocalDate a1 = now.minusMonths(2).withDayOfMonth(26);
            LocalDate a2 = now.minusMonths(1).withDayOfMonth(25);
            return lineMapper.searchCityCount(a1, a2);
        } else {
            LocalDate a1 = now.minusMonths(1).withDayOfMonth(26);
            LocalDate a2 = now.withDayOfMonth(25);
            return lineMapper.searchCityCount(a1, a2);
        }
    }

    /**
     * 根据车辆id查询线路,装备,人员,标的
     */
    @Override
    public GetCarIdInfoResponse getCarIdInfo(String id) {
        //获取该车辆的任务id
        String bcs = lineMapper.getByCarId(id);
        GetCarIdInfoResponse res = new GetCarIdInfoResponse();
        res.setZbList(lineMapper.equip(bcs));
        res.setUserList(lineMapper.userInfo(bcs));
        res.setBdwInfo(lineMapper.items(bcs));
        SelectLineInfoResponse se = lineMapper.selectLineInfo(bcs);
        if (BeanUtil.isNotEmpty(se)) {
            res.setLineType(se.getType());
        }
        return res;
    }
}
